<?php

namespace Pusher\Jobs;

use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Foundation\Bus\Dispatchable;
use Illuminate\Queue\InteractsWithQueue;
use Illuminate\Queue\SerializesModels;

class RegisterEventJob implements ShouldQueue
{
    use Dispatchable, InteractsWithQueue, Queueable, SerializesModels;

    /**
     * 事件ID
     *
     * @var int
     */
    protected $eventId;

    /**
     * 装载参数
     *
     * @var array
     */
    protected $payload;

    /**
     * 事件注册时分发的job
     *
     * @param int $eventId 如果事件未注册模板，注册的事件将会被舍弃
     * @param array $payload 必须为数组形式的map，不能包含list
     */
    public function __construct(int $eventId, array $payload)
    {
        $this->eventId = $eventId;
        $this->payload = $payload;
    }

    public function handle()
    {
        $handler = config('push.handler-map.' . RegisterEventJob::class);

        if ($handler) {
            dispatch_now(new $handler($this->eventId, $this->payload));
        }
    }
}